@@ -202,6 +202,13 @@ class   ExtGState:
         x._c = self._c
         return x
 
+def _gradientExtendStr(extend):
+    if isinstance(extend,(list,tuple)):
+        if len(extend)!=2:
+            raise ValueError('wrong length for extend argument' % extend)
+        return "[%s %s]" % ['true' if _ else 'false' for _ in extend]
+    return "[true true]" if extend else "[false false]"
+
 class Canvas(_PDFColorSetter):
     """This class is the programmer's interface to the PDF file format.  Methods
     are (or will be) provided here to do just about everything PDF can do.
@@ -867,7 +874,8 @@ class Canvas(_PDFColorSetter):
     #
     ######################################################
     def drawInlineImage(self, image, x,y, width=None,height=None,
-            preserveAspectRatio=False,anchor='c', anchorAtXY=False, showBoundary=False):
+            preserveAspectRatio=False,anchor='c', anchorAtXY=False, showBoundary=False,
+            extraReturn=None):
         """See drawImage, which should normally be used instead... 
         
         drawInlineImage behaves like drawImage, but stores the image content
@@ -886,11 +894,13 @@ class Canvas(_PDFColorSetter):
         img_obj = PDFImage(image, x,y, width, height)
         img_obj.drawInlineImage(self,
             preserveAspectRatio=preserveAspectRatio, 
-            anchor=anchor,anchorAtXY=anchorAtXY,showBoundary=showBoundary)
+            anchor=anchor,anchorAtXY=anchorAtXY,showBoundary=showBoundary,
+            extraReturn=extraReturn)
         return (img_obj.width, img_obj.height)
 
     def drawImage(self, image, x, y, width=None, height=None, mask=None, 
-            preserveAspectRatio=False, anchor='c', anchorAtXY=False, showBoundary=False):
+            preserveAspectRatio=False, anchor='c', anchorAtXY=False, showBoundary=False,
+            extraReturn=None):
         """Draws the image (ImageReader object or filename) as specified.
 
         "image" may be an image filename or an ImageReader object. 
@@ -1003,10 +1013,14 @@ class Canvas(_PDFColorSetter):
         self._code.append("/%s Do" % regName)
         self.restoreState()
         if showBoundary:
-            self.rect(x,y,width,height,stroke=1,fill=0)
+            #self.rect(x,y,width,height,stroke=1,fill=0)
+            self.drawBoundary(showBoundary,x,y,width,height)
 
         # track what's been used on this page
         self._formsinuse.append(name)
+        if extraReturn:
+            for k in extraReturn.keys():
+                extraReturn[k] = vars()[k]
 
         return (imgObj.width, imgObj.height)
 
@@ -1557,12 +1571,8 @@ class Canvas(_PDFColorSetter):
         from reportlab.pdfbase.pdfdoc import PDFAxialShading
         colorSpace, ncolors = _normalizeColors(colors)
         fcn = _buildColorFunction(ncolors, positions)
-        if extend:
-            extendStr = "[true true]"
-        else:
-            extendStr = "[false false]"
         shading = PDFAxialShading(x0, y0, x1, y1, Function=fcn,
-                ColorSpace=colorSpace, Extend=extendStr)
+                ColorSpace=colorSpace, Extend=_gradientExtendStr(extend))
         self.shade(shading)
 
     def radialGradient(self, x, y, radius, colors, positions=None, extend=True):
@@ -1570,12 +1580,8 @@ class Canvas(_PDFColorSetter):
         from reportlab.pdfbase.pdfdoc import PDFRadialShading
         colorSpace, ncolors = _normalizeColors(colors)
         fcn = _buildColorFunction(ncolors, positions)
-        if extend:
-            extendStr = "[true true]"
-        else:
-            extendStr = "[false false]"
         shading = PDFRadialShading(x, y, 0.0, x, y, radius, Function=fcn,
-                ColorSpace=colorSpace, Extend=extendStr)
+                ColorSpace=colorSpace, Extend=_gradientExtendStr(extend))
         self.shade(shading)
 
         ##################################################
