@@ -3,7 +3,7 @@
 """
 Tests for chart class.
 """
-from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation, rlextraNeeded
+from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation, rlextraNeeded, haveRenderPM, rlSkipIf
 setOutDir(__name__)
 
 import os, sys, copy
@@ -32,9 +32,10 @@ from reportlab.graphics.widgets.markers import makeMarker
 from reportlab.graphics.widgets.adjustableArrow import AdjustableArrowDrawing
 
 try:
-    from reportlab.graphics import _renderPM
+    from reportlab.graphics import renderPM
+    if not haveRenderPM(): renderPM = None
 except ImportError:
-    _renderPM = None
+    renderPM = None
 
 def getFontName():
     try:
@@ -331,10 +332,18 @@ def eps():
 
 def run_samples(L):
     outDir = outputfile('charts-out')
-    for k,f,kind in L:
-        d = f()
-        if not isinstance(d,Drawing): continue
-        d.save(formats=['pdf', 'gif', 'svg', 'ps', 'py']+eps(),outDir=outDir, fnRoot='test_graphics_charts_%s_%s' % (kind,k))
+    global fontName
+    oFontName = fontName
+    def innerRun(formats):
+        for k,f,kind in L:
+            d = f()
+            if not renderPM: d.__dict__['preview'] = 0
+            if not isinstance(d,Drawing): continue
+            d.save(formats=formats,outDir=outDir, fnRoot='test_graphics_charts_%s_%s' % (kind,k))
+    innerRun(['pdf']+(['gif'] if renderPM else [])+['svg', 'py']+eps())
+    fontName = 'Helvetica'
+    innerRun(['ps'])
+    fontName = oFontName
 
 class ChartTestCase(unittest.TestCase):
     "Test chart classes."
@@ -353,8 +362,6 @@ class ChartTestCase(unittest.TestCase):
         doc = MyDocTemplate(path)
         doc.build(cls.story)
 
-        global fontName
-        fontName = 'Helvetica'
         run_samples([(k,v,'special') for k,v in globals().items() if k.lower().startswith('sample')
                             or k in ('lpleg', 'hlcleg', 'bcleg', 'pcleg', 'scleg', 'plpleg')
                             ])
@@ -519,7 +526,7 @@ class ChartTestCase(unittest.TestCase):
             story.append(makeArrow(y=-10,x=deltax*i,angle=angle,strokeColor=colors.black,strokeWidth=0.5,headSweep=-i*0.6))
         story.append(Spacer(0,1*cm))
 
-    @unittest.skipIf(not _renderPM,'no _renderPM')
+    @rlSkipIf(not renderPM,'no renderPM')
     def test8(self):
         '''text _text2Path'''
         story = self.story
@@ -620,42 +627,6 @@ class ChartTestCase(unittest.TestCase):
             drawing.add(xAxis)
             return drawing
 
-        @unittest.skipIf(rlextraNeeded(),'s')
-        def sample0c():
-            "Sample drawing with one xcat axis and two buckets."
-            class DDFStyle(ParagraphStyle):
-                def __init__(self,**kwds):
-                    if 'fillColor' in kwds:
-                        kwds['textColor'] = kwds.pop('fillColor')
-                    kwds.update({k:v for k,v in (
-                                    ('name','DDFStyle'),
-                                    ('alignment',0),
-                                    ('hyphenationLang',None),
-                                    ('hyphenationMinWordLength',4),
-                                    ('uriWasteReduce',0.3),
-                                    ('embeddedHyphenation',2),
-                                    ('textColor',colors.blue),
-                                    ('backColor',colors.yellow),
-                                    ) if k not in kwds})
-                    super().__init__(**kwds)
-
-            drawing = Drawing(400, 200)
-            data = [(10, 20)]
-            xAxis = XCategoryAxis()
-            xAxis.labels.ddfKlass = Paragraph
-            xAxis.labels.ddfStyle = DDFStyle
-            xAxis.labels.maxWidth = 48
-            xAxis.labels.fillColor = colors.red
-            xAxis.labels.fontName = 'Helvetica'
-            xAxis.labels.fontSize = 12
-            xAxis.labels.leading = 12
-            xAxis.setPosition(75, 75, 100)
-            xAxis.configure(data)
-            xAxis.categoryNames = ['Ying and Mao\xadTse\xadTung are bonkers', 'Yang is not a comm\xadun\xadist']
-            xAxis.labels.boxAnchor = 'n'
-            drawing.add(xAxis)
-            return drawing
-
         def sample1():
             "Sample drawing containing two unconnected axes."
             from reportlab.graphics.shapes import _baseGFontNameB
@@ -1098,6 +1069,45 @@ class ChartTestCase(unittest.TestCase):
         run_samples([(k,v,'axes') for k,v in locals().items() if k.lower().startswith('sample')])
         run_samples(extract_samples())
 
+    @rlSkipIf(rlextraNeeded(),'rlextra needed')
+    def test_axes_rlx(self):
+        from reportlab.graphics.charts.axes import YValueAxis, XValueAxis, LogYValueAxis, LogXValueAxis, LogYValueAxis, XCategoryAxis, YCategoryAxis
+        def sample0c():
+            "Sample drawing with one xcat axis and two buckets."
+            class DDFStyle(ParagraphStyle):
+                def __init__(self,**kwds):
+                    if 'fillColor' in kwds:
+                        kwds['textColor'] = kwds.pop('fillColor')
+                    kwds.update({k:v for k,v in (
+                                    ('name','DDFStyle'),
+                                    ('alignment',0),
+                                    ('hyphenationLang',None),
+                                    ('hyphenationMinWordLength',4),
+                                    ('uriWasteReduce',0.3),
+                                    ('embeddedHyphenation',2),
+                                    ('textColor',colors.blue),
+                                    ('backColor',colors.yellow),
+                                    ) if k not in kwds})
+                    super().__init__(**kwds)
+
+            drawing = Drawing(400, 200)
+            data = [(10, 20)]
+            xAxis = XCategoryAxis()
+            xAxis.labels.ddfKlass = Paragraph
+            xAxis.labels.ddfStyle = DDFStyle
+            xAxis.labels.maxWidth = 48
+            xAxis.labels.fillColor = colors.red
+            xAxis.labels.fontName = 'Helvetica'
+            xAxis.labels.fontSize = 12
+            xAxis.labels.leading = 12
+            xAxis.setPosition(75, 75, 100)
+            xAxis.configure(data)
+            xAxis.categoryNames = ['Ying and Mao\xadTse\xadTung are bonkers', 'Yang is not a comm\xadun\xadist']
+            xAxis.labels.boxAnchor = 'n'
+            drawing.add(xAxis)
+            return drawing
+        run_samples([(k,v,'axes') for k,v in locals().items() if k.lower().startswith('sample')])
+
     def test_legends(self):
         from reportlab.graphics.charts.legends import Legend, LineLegend, LineSwatch
 
